@@ -7,7 +7,7 @@ from typing import Dict
 import uvicorn
 from fastapi import FastAPI
 
-from fidesapi import crud, db_session
+from fidesapi import crud, db_session, visualize
 from fidesctl.core.config import get_config
 
 app = FastAPI()
@@ -17,6 +17,9 @@ def configure_routes() -> None:
     "Include all of the routers not defined here."
     for router in crud.routers:
         app.include_router(router)
+    # add router for the category viz endpoints
+    for router in visualize.routers:
+        app.include_router(router)
 
 
 def configure_db(database_url: str) -> None:
@@ -24,7 +27,7 @@ def configure_db(database_url: str) -> None:
     db_session.global_init(database_url)
 
 
-@app.get("/", tags=["Healthcheck"])
+@app.get("/health", tags=["Healthcheck"])
 async def healthcheck() -> Dict:
     "Define a simple healthcheck endpoint that will confirm if the API is running."
     return {"data": {"message": "Fides service is healthy!"}}
