@@ -30,6 +30,7 @@ class FidesBase(SqlModelBase):
 SqlAlchemyBase = sqlalchemy.ext.declarative.declarative_base(cls=SqlModelBase)
 
 
+# Privacy Types
 class DataCategory(SqlAlchemyBase, FidesBase):
     """
     The SQL model for the DataCategory resource.
@@ -47,6 +48,8 @@ class DataQualifier(SqlAlchemyBase, FidesBase):
 
     __tablename__ = "data_qualifiers"
 
+    parent_key = Column(Text)
+
 
 class DataSubject(SqlAlchemyBase, FidesBase):
     """
@@ -76,7 +79,7 @@ class Dataset(SqlAlchemyBase, FidesBase):
 
     meta = Column(JSON)
     data_categories = Column(ARRAY(String))
-    data_qualifier = Column(ARRAY(String))
+    data_qualifiers = Column(ARRAY(String))
     collections = Column(JSON)
 
 
