@@ -1,4 +1,6 @@
 """Contains all of the CLI commands for Fides."""
+import pprint
+
 import click
 
 from fidesapi.main import start_webserver
@@ -8,6 +10,8 @@ from fidesctl.cli.options import (
     fides_key_argument,
     manifests_dir_argument,
     resource_type_argument,
+    yes_flag,
+    verbose_flag,
 )
 from fidesctl.cli.utils import (
     handle_cli_response,
@@ -20,6 +24,7 @@ from fidesctl.core import (
     generate_dataset as _generate_dataset,
     parse as _parse,
 )
+from fidesctl.core.utils import echo_green, echo_red
 
 
 @click.command()
@@ -36,9 +41,10 @@ def apply(ctx: click.Context, dry: bool, diff: bool, manifests_dir: str) -> None
     Send the manifest files to the server.
     """
     config = ctx.obj["CONFIG"]
+    taxonomy = _parse.parse(manifests_dir)
     _apply.apply(
         url=config.cli.server_url,
-        manifests_dir=manifests_dir,
+        taxonomy=taxonomy,
         headers=config.user.request_headers,
         dry=dry,
         diff=diff,
@@ -94,9 +100,10 @@ def evaluate(
     """
 
     config = ctx.obj["CONFIG"]
+    taxonomy = _parse.parse(manifests_dir)
     _apply.apply(
         url=config.cli.server_url,
-        manifests_dir=manifests_dir,
+        taxonomy=taxonomy,
         headers=config.user.request_headers,
         dry=dry,
     )
@@ -157,7 +164,7 @@ def init_db(ctx: click.Context) -> None:
     Initialize or upgrade the database by running all of the existing migrations.
     """
     config = ctx.obj["CONFIG"]
-    database.init_db(config.api.database_url)
+    database.init_db(config.api.database_url, fidesctl_config=config)
 
 
 @click.command()
@@ -180,12 +187,15 @@ def ls(ctx: click.Context, resource_type: str) -> None:  # pylint: disable=inval
 @click.command()
 @click.pass_context
 @manifests_dir_argument
-def parse(ctx: click.Context, manifests_dir: str) -> None:
+@verbose_flag
+def parse(ctx: click.Context, manifests_dir: str, verbose: bool = False) -> None:
     """
     Parse the file(s) at the provided path into a Taxonomy and surface any validation errors.
     """
 
-    _parse.parse(manifests_dir)
+    taxonomy = _parse.parse(manifests_dir)
+    if verbose:
+        pprint.pprint(taxonomy)
 
 
 @click.command()
@@ -195,24 +205,31 @@ def ping(ctx: click.Context, config_path: str = "") -> None:
     Ping the Server.
     """
     config = ctx.obj["CONFIG"]
-    click.secho(f"Pinging {config.cli.server_url}...", fg="green")
-    _api.ping(config.cli.server_url)
-    click.secho("Ping Successful!", fg="green")
+    healthcheck_url = config.cli.server_url + "/health"
+    echo_green(f"Pinging {healthcheck_url}...")
+    handle_cli_response(_api.ping(healthcheck_url))
 
 
 @click.command()
 @click.pass_context
-def reset_db(ctx: click.Context) -> None:
+@yes_flag
+def reset_db(ctx: click.Context, yes: bool) -> None:
     """
-    Drop all tables and metadata from the database.
+    Drops all tables and metadata from the database and
+    re-initializes the database.
     """
     config = ctx.obj["CONFIG"]
-    are_you_sure = input(
-        "This will drop all data from the Fides database! Are you sure [y/n]?"
-    )
+    database_url = config.api.database_url
+    if yes:
+        are_you_sure = "y"
+    else:
+        echo_red("This will drop all data from the Fides database!")
+        are_you_sure = input("Are you sure [y/n]?")
+
     if are_you_sure.lower() == "y":
-        database.reset_db(config.api.database_url)
-        print("Database reset!")
+        database.reset_db(database_url)
+        database.init_db(database_url, config)
+        echo_green("Database reset!")
     else:
         print("Aborting!")
 
