@@ -5,13 +5,14 @@ import sqlalchemy
 from sqlalchemy.engine import Engine
 
 from fideslang import manifests
+from fideslang.models import Dataset, DatasetCollection, DatasetField
 from .utils import get_db_engine, echo_green
 
 
-def get_db_tables(engine: Engine) -> Dict[str, List[str]]:
+def get_db_collections_and_fields(engine: Engine) -> Dict[str, List[str]]:
     """
     Return an object containing all of the tables within
-    a database and their columns
+    a database and their fields.
     """
     inspector = sqlalchemy.inspect(engine)
     db_tables = {
@@ -23,53 +24,46 @@ def get_db_tables(engine: Engine) -> Dict[str, List[str]]:
     return db_tables
 
 
-def generate_table_manifests(
+def create_dataset_collections(
     db_tables: Dict[str, List[str]]
-) -> List[Dict[str, object]]:
+) -> List[DatasetCollection]:
     """
     Return an object of tables and columns formatted for a Fides manifest
     with dummy values where needed.
     """
+
     table_manifests = [
-        {
-            "name": table,
-            "description": f"Fides Generated Description for Table: {table}",
-            "dataset_fields": [
-                {
-                    "name": column,
-                    "description": f"Fides Generated Description for Column: {column}",
-                    "data_categories": [],
-                }
+        DatasetCollection(
+            name=table,
+            description=f"Fides Generated Description for Table: {table}",
+            fields=[
+                DatasetField(
+                    name=column,
+                    description=f"Fides Generated Description for Column: {column}",
+                    data_categories=[],
+                )
                 for column in db_tables[table]
             ],
-        }
+        )
         for table in db_tables.keys()
     ]
     return table_manifests
 
 
-def generate_dataset_info(engine: Engine) -> Dict[str, List]:
+def create_dataset(engine: Engine, collections: List[DatasetCollection]) -> Dataset:
     """
     Generate a partial dataset manifest, sans tables/fields,
     given a database engine.
     """
     url = engine.url
     name = url.database
-    dataset_type = engine.name
-    dataset_location = f"{url.host}:{url.port}"
-    dataset_info = {
-        "dataset": [
-            {
-                "organization_fides_key": 1,
-                "fides_key": name,
-                "name": name,
-                "description": f"Fides Generated Description for Dataset: {name}",
-                "dataset_type": dataset_type,
-                "dataset_location": dataset_location,
-            }
-        ]
-    }
-    return dataset_info
+    dataset = Dataset(
+        fides_key=name,
+        name=name,
+        description=f"Fides Generated Description for Dataset: {name}",
+        collections=collections,
+    )
+    return dataset
 
 
 def generate_dataset(connection_string: str, file_name: str) -> None:
@@ -78,9 +72,8 @@ def generate_dataset(connection_string: str, file_name: str) -> None:
     and write out a boilerplate dataset manifest.
     """
     db_engine = get_db_engine(connection_string)
-    db_tables = get_db_tables(db_engine)
-    table_manifests = generate_table_manifests(db_tables)
-    dataset_info = generate_dataset_info(db_engine)
-    dataset_info["dataset"][0]["datasetTables"] = table_manifests
-    manifests.write_manifest(file_name, dataset_info)
+    db_collections = get_db_collections_and_fields(db_engine)
+    collections = create_dataset_collections(db_collections)
+    dataset = create_dataset(db_engine, collections)
+    manifests.write_manifest(file_name, dataset.dict(), "dataset")
     echo_green(f"Generated dataset manifest written to {file_name}")
